@@ -1,6 +1,6 @@
 #
 #
-# Copyright (c) 2021 DPS, dps@my.mail.de
+# Copyright (c) 2020-2021 DPS, dps@my.mail.de
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,10 +18,9 @@
 #
 
 
-
-__all__ = ["Dpowers","autoadapt","sleep","launch","Icon","Win",
-    "keyb", "mouse","ntfy","dlg","hotkeys","hook","sendwait","nfsendwait",
-    "clip", "Dfuncs","events", "KeyWaiter", "Image", "mp3tag", "Dhelpers"]
+__all__ = ["autoadapt", "keyb", "mouse", "ntfy", "dlg", "hook", "Icon", "Win",
+    "sendwait", "nfsendwait", "clip", "Dfuncs", "events", "KeyWaiter", "Image",
+    "mp3tag", "sleep", "hotkeys","launch", "Dpowers", "Dhelpers"]
 
 import os, sys
 from time import sleep
@@ -39,14 +38,17 @@ except ModuleNotFoundError:
     import Dhelpers
     
 
-__version__ = "0.1.0"
+__version__ = "0.1.1"
 from Dhelpers import __version__  as Dhelpers_version
 #Dpowers and Dhelpers share version number
 if __version__ != Dhelpers_version: raise ValueError
 
-from Dhelpers.all import (always_print_traceback, restore_print_func,
-    launch, AdaptorBase, adaptionmethod, AdaptionError, ArgSaver, Layout,
-    AdaptorBase, adaptionmethod, AdaptiveClass)
+from Dhelpers.adaptor import (AdaptorBase, adaptionmethod, AdaptionError,
+    AdaptorBase, adaptionmethod, AdaptiveClass, DependencyManager)
+from Dhelpers.launcher import launch
+from Dhelpers.customprint import always_print_traceback, restore_print_func
+from Dhelpers.arghandling import ArgSaver
+from Dhelpers.KeyboardLayouts import Layout
 
     
 try:
