@@ -1,6 +1,6 @@
 #
 #
-# Copyright (c) 2021 DPS, dps@my.mail.de
+# Copyright (c) 2020-2021 DPS, dps@my.mail.de
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,8 +30,8 @@ class hotkeys:
                     with cls.paused(timeout): return func(*args, **kwargs)
                 else:
                     return func(*args, **kwargs)
-            function_with_hotkey_pause.__signature__ = add_kw_only_arg(func,
-                    "pause_hotkeys", default=default_pause_value)
+            #function_with_hotkey_pause.__signature__ = add_kw_only_arg(func,
+             #       "pause_hotkeys", default=default_pause_value)
             return function_with_hotkey_pause
         return wrapper_function
     
