@@ -1,6 +1,6 @@
 #
 #
-# Copyright (c) 2021 DPS, dps@my.mail.de
+# Copyright (c) 2020-2021 DPS, dps@my.mail.de
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,7 +16,8 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 #
 #
-from Dhelpers.all import AdditionContainer, NamedObj
+from Dhelpers.baseclasses import AdditionContainer
+from Dhelpers.named import NamedObj
 from . import hotkeys
 from abc import ABC, abstractmethod
 from time import sleep
