@@ -1,6 +1,6 @@
 #
 #
-# Copyright (c) 2021 DPS, dps@my.mail.de
+# Copyright (c) 2020-2021 DPS, dps@my.mail.de
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,7 +17,9 @@
 #
 #
 from warnings import warn
-from Dhelpers.all import container, AdditionContainer, check_type, TimedObject
+from Dhelpers.baseclasses import AdditionContainer, TimedObject
+from Dhelpers.container import container
+from Dhelpers.arghandling import check_type
 from abc import ABC, abstractmethod
 import threading, queue, logging, inspect, functools, traceback
 from ..event_classes import MouseMoveEvent
