@@ -1,6 +1,6 @@
 #
 #
-# Copyright (c) 2021 DPS, dps@my.mail.de
+# Copyright (c) 2020-2021 DPS, dps@my.mail.de
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,6 +23,14 @@ from ..event_sender import AdaptiveSender, AdaptivePressReleaseSender
 
 class SenderAdaptorMixin:
     
+    
+    default_delay = 0
+    """
+    .. exec::
+
+        event_sender.default_delay_doc("events")
+    """
+    
     def __init__(self, *args,**kwargs):
         super().__init__(*args, **kwargs)
         self.selected_devs = []
@@ -39,7 +47,13 @@ class SenderAdaptor(SenderAdaptorMixin, AdaptiveSender):
     # inherits adaptionmethod _press
     pass
 
-
 class PressReleaseSenderAdaptor(SenderAdaptorMixin, AdaptivePressReleaseSender):
+    
     # inherits adaptionmethods _press and _rls
-    pass
\ No newline at end of file
+    
+    default_duration = 1
+    """
+    .. exec::
+
+        event_sender.default_duration_doc("event object")
+    """
\ No newline at end of file
