@@ -1,6 +1,6 @@
 #
 #
-# Copyright (c) 2021 DPS, dps@my.mail.de
+# Copyright (c) 2020-2021 DPS, dps@my.mail.de
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,10 @@ from . import NamedKey, keyb, NamedButton
 from .event_classes import StringAnalyzer, EventCombination, EventSequence, \
     StringEvent
 from .hookpower import HookAdaptor
-from Dhelpers.all import launch, TimedObject, dpress, check_type
+from Dhelpers.launcher import launch
+from Dhelpers.baseclasses import TimedObject
+from Dhelpers.arghandling import check_type
+from Dhelpers.counting import dpress
 import collections
 
 
