@@ -1,6 +1,6 @@
 #
 #
-# Copyright (c) 2021 DPS, dps@my.mail.de
+# Copyright (c) 2020-2021 DPS, dps@my.mail.de
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,9 @@
 #
 from . import HookAdaptor, CallbackHook, hotkeys, KeyboardAdaptor, \
     MouseAdaptor
-from Dhelpers.all import check_type, launch, TimedObject
+from Dhelpers.arghandling import check_type
+from Dhelpers.baseclasses import TimedObject
+from Dhelpers.launcher import launch
 import time
 from .. import NotificationAdaptor
 
